dlnasrv_exampleapp/src/exampleappui.cpp
branchIOP_Improvements
changeset 43 9b689d9d3a1c
parent 41 b4d83ea1d6e2
--- a/dlnasrv_exampleapp/src/exampleappui.cpp	Wed Nov 03 12:18:00 2010 +0200
+++ b/dlnasrv_exampleapp/src/exampleappui.cpp	Fri Nov 05 18:31:17 2010 +0200
@@ -375,9 +375,9 @@
         
         // update text to ui
         QFileInfo fileInfo(mSelectedFile);
         // use only 20 characters to fit text on screen 
         // since otherwise qt will panic with bad alloc
-        mSelectedFileLabel->setText(fileInfo.fileName().left(20));
+        mSelectedFileLabel->setText(fileInfo.fileName().left(16));
        
         // resolve and init file for rendering
         int err = mEngine->initFile(mSelectedFile);
@@ -375,9 +375,9 @@
         // update text to ui
         QFileInfo fileInfo(mSelectedFile);
-        // use only 20 characters to fit text on screen 
+        // use only 16 characters to fit text on screen 
         // since otherwise qt will panic with bad alloc